@@ -194,8 +194,10 @@ class ElementNoFound(BaseException):
 class YamlParseError(BaseException):
     """Pyyaml解析错误抛出的异常"""
     def __init__(self, error):
-        self.msg = error.__context__
-        BaseException.__init__(self, self.msg)
+        self.msg = '解析yaml文件报错'
+        context = str(error[0]) + ': ' + error[1]
+        problem = str(error[2]) + ': ' + error[3]
+        BaseException.__init__(self, self.msg, context, problem)
 
 
 class RuntimeArgNoFound(BaseException):
