@@ -2,7 +2,7 @@
 from gtest.model.options import Options
 from gtest.model.suite_file_tree import SuiteFileTree
 from gtest.model.suite_tree import SuiteTree
-from gtest.runner.base_runner import RunnerFactory
+from gtest.runner.base_runner import runner_factory
 from gtest.utils.opt_parser import OptionParser
 from gtest.utils.output import Output
 from gtest.utils.logger import logger
@@ -12,7 +12,7 @@ import sys
 
 
 class GTest(object):
-    version = '0.1.4'
+    version = '0.1.5'
 
     def __init__(self, path, options):
         self.opt = Options(path, options, self.version)
@@ -24,7 +24,7 @@ class GTest(object):
         try:
             file_tree = SuiteFileTree(self.path, self.opt)  # 先解析目录文件结构
             suite_tree = SuiteTree(file_tree, self.opt)  # 再生成数据树
-            runner = RunnerFactory(self.opt.run_mode, suite_tree, self.opt)  # 执行用例
+            runner = runner_factory(self.opt.run_mode, suite_tree, self.opt)  # 执行用例
             '''miss: show result'''
         except Exception as e:
             if isinstance(e, BaseException):
