@@ -24,10 +24,12 @@ class SuiteFile(Node):
         if not source or 'case' not in source:
             return None
         cases = list()
-        for case in source['case']:
-            if 'name' in case:
-                cases.append({'name': case['name'],
-                              'tag': self.load_tag(case)})
+        for i in range(0, len(source['case'])):
+            if 'name' in source['case'][i]:
+                cases.append({'name': source['case'][i]['name'],
+                              'tag': self.load_tag(source['case'][i]),
+                              'case_source': source['case'][i],
+                              'source': source['case']})
         return cases
 
     def load_tag(self, source):
@@ -100,10 +102,9 @@ class SuiteFileTree(object):
 
     def parse_selection(self, options):
         '''通过tag筛选'''
-        selected_tag = options.tag
-        if selected_tag:
-            if not self._parse_selection(self.root, selected_tag):
-                raise NoCaseMatch(selected_tag)
+        if options.tag:
+            if not self._parse_selection(self.root, options.tag):
+                raise NoCaseMatch(options.tag)
 
     def _parse_selection(self, root, tag):
         if root.tag and self.match_tag(root.tag, tag):
@@ -120,11 +121,15 @@ class SuiteFileTree(object):
                 return True
             else:
                 return False
+        elif root.case:
+            for case in root.case:
+                if not case['tag'] or not self.match_tag(case['tag'], tag):
+                    case['source'].remove(case['case_source'])
         else:
             return False
 
-    def match_tag(self, suite_tag, selected_tag):
-        for tag in suite_tag:
+    def match_tag(self, tags, selected_tag):
+        for tag in tags:
             if tag in selected_tag:
                 return True
             else:
