@@ -5,6 +5,7 @@ from selenium.common.exceptions import WebDriverException
 from selenium.webdriver.chrome.options import Options
 from gtest.utils.logger import logger
 from gtest.model.matcher.var_matcher import VarMatcher
+from gtest.keyword_.common import *
 from gtest.exceptions import *
 import time
 
@@ -76,14 +77,14 @@ class BaseRunner:
                 r_node['child'].append(child_d)
 
     def _get_pre_and_post(self, s_node, _type):
-        l = list()
+        stage = list()
         c_node = s_node
-        l.insert(0, getattr(c_node, _type))
+        stage.insert(0, getattr(c_node, _type))
         while c_node.parent is not None:  # 循环查找其父suite是否有setup/teardown
             c_node = c_node.parent
-            l.insert(0, getattr(c_node, _type))
-        l = [item for item in l if item is not None]  # 去除值为None的setup/teardown
-        return l
+            stage.insert(0, getattr(c_node, _type))
+        stage = [item for item in stage if item is not None]  # 去除值为None的setup/teardown
+        return stage
 
     @contextmanager
     def run_session(self):
@@ -103,17 +104,20 @@ class BaseRunner:
         logger.info('执行测试套件: {}'.format(suite['name']))
         self.run_setup(suite['name'], suite['setup'], '测试套件')
         logger.add_prefix()
-        try:
-            for i in range(0, len(suite['cases'])):
+        for i in range(0, len(suite['cases'])):
+            try:
                 self.run_case(suite['cases'][i], suite['result'][i])
-        except Exception as e:
-            raise e
-        finally:
-            logger.sub_prefix()
-            self.run_teardown(suite['name'], suite['teardown'], '测试套件')
-            '''清除浏览器环境，保证在当前窗口中下一个suite执行时有一个新页面和干净的cookies'''
-            if suite != self.suite_list[-1]:
-                self._delete_close_and_open()
+            except Exception as e:
+                if isinstance(e, BaseException):
+                    pass
+                else:
+                    raise e
+            finally:
+                logger.sub_prefix()
+                self.run_teardown(suite['name'], suite['teardown'], '测试套件')
+                '''清除浏览器环境，保证在当前窗口中下一个suite执行时有一个新页面和干净的cookies'''
+                if suite != self.suite_list[-1]:
+                    self.reset_driver()
 
     def run_case(self, case, _result):
         pass
@@ -161,39 +165,24 @@ class BaseRunner:
                     arg = '{}={}'.format(name, self._check_value(value['value'], 'keyword')) if value['value'] else None
                     s += ', ' + arg if arg else ''
             if keyword.inner_args:
-                exec_command = 'self.r = keyword.func(self.driver, *a{})'.format(s)
+                if keyword.name == 'new_browser':
+                    self.reset_driver()
+                else:
+                    exec_command = 'self.r = keyword.func(self.driver, *a{})'.format(s)
+                    exec(exec_command)
             else:
                 exec_command = 'self.r = keyword.func(*a{})'.format(s)
+                exec(exec_command)
             if hasattr(step_info, 'description') and step_info.description:
                 logger.info('执行步骤: 类型{}, 关键字{}, 描述:{}'.format(step_info.type, keyword.name, step_info.description))
             else:
                 logger.info('执行步骤: 类型{}, 关键字{}'.format(step_info.type, keyword.name))
-            exec(exec_command)
             if step_info.type == 'keyword' and step_info.return_var:
                 self.dyn_var[step_info.return_var[0]] = self.r
                 return True
             else:
                 return self.r
 
-    # 关闭窗口删除cookies并打开新的窗口（适用于登录注册）
-    def _delete_close_and_open(self):
-        '''
-        self.driver.delete_all_cookies()  # 清除cookies
-        self.driver.execute_script('window.open()')
-        self.driver.close()
-        time.sleep(1)
-        input()
-        self.driver.switch_to.window(self.driver.window_handles[-1])
-        '''
-        self.driver.quit()
-        self.driver = self.load_driver()
-
-    # 关闭窗口并打开新的窗口
-    def _close_and_open(self):
-        self.driver.execute_script('window.open()')
-        self.driver.close()
-        self.driver.switch_to.window(self.driver.window_handles[-1])
-
     def _count_time(self, start_time):
         end_time = round(time.time(), 2)
         use_time = end_time - start_time
@@ -221,6 +210,11 @@ class BaseRunner:
     def refresh_dyn(self):
         self.dyn_var = dict()
 
+    def reset_driver(self):
+        self.driver.quit()
+        self.driver = self.load_driver()
+        self.driver.maximize_window()
+
     def load_driver(self):
         chrome_options = Options()
         chrome_options.add_argument('--no-sandbox')
@@ -231,15 +225,23 @@ class BaseRunner:
             driver = WebDriver(executable_path=self.option.driver_path, options=chrome_options)
             return driver
         import os
-        driver_file = None
+        driver_path = None
         if os.path.isdir(self.option.run_path):  # 检查run_path下是否有driver文件
             driver_file = None
             for file in os.listdir(self.option.run_path):
                 if file.startswith('chromedriver'):
                     driver_file = file
-        if driver_file:
+            driver_path = os.path.join(self.option.run_path, driver_file) if driver_file else None
+        elif os.path.isfile(self.option.run_path):
+            dir_path = os.path.dirname(os.path.abspath(self.option.run_path))
+            driver_file = None
+            for file in os.listdir(dir_path):
+                if file.startswith('chromedriver'):
+                    driver_file = file
+            driver_path = os.path.join(dir_path, driver_file) if driver_file else None
+        if driver_path:
             try:
-                driver = WebDriver(executable_path=os.path.join(self.option.run_path, driver_file), options=chrome_options)
+                driver = WebDriver(executable_path=driver_path, options=chrome_options)
             except WebDriverException:
                 driver = WebDriver(options=chrome_options)
         else:
@@ -247,7 +249,7 @@ class BaseRunner:
         return driver
 
 
-def RunnerFactory(run_mode, suite_tree, option):
+def runner_factory(run_mode, suite_tree, option):
     if run_mode == 'default':
         from gtest.runner.default_runner import DefaultRunner
         return DefaultRunner(suite_tree, option)
