@@ -2,12 +2,16 @@
 from gtest.runner.base_runner import BaseRunner
 from gtest.utils.logger import logger
 from gtest.keyword_.selenium_ import find_elements
+from gtest.keyword_.common import *
 import time
 
 
 class DebugRunner(BaseRunner):
+    def __init__(self, suite_tree, option):
+        BaseRunner.__init__(self, suite_tree, option)
+
     def run_case(self, case, _result):
-        logger.info('执行用例: {} {}'.format(case.name, case.description))
+        logger.info('执行用例: {}'.format(case.name))
         print('调试模式,点击<ENTER>继续, 或输入q退出调试:')
         start_time = round(time.time(), 2)
         self.run_setup(case.name, case.setup, '用例')
@@ -28,11 +32,11 @@ class DebugRunner(BaseRunner):
                 logger.debug('用例执行成功: {} {}, 用时: {}'.format(case.name, case.description, self._count_time(start_time)))
             else:
                 _result['result'] = False
-                logger.debug('用例执行失败: {} {}, 用时: {}'.format(case.name, case.description, self._count_time(start_time)))
+                logger.debug('用例执行失败: {}, 用时: {}'.format(case.name, self._count_time(start_time)))
             self.run_teardown(case.name, case.teardown, '用例(Case)')
             '''清除浏览器环境，保证在当前窗口中下一个suite执行时有一个新页面和干净的cookies'''
             self._input('再次点击<ENTER>退出测试')
-            self._close_and_open()
+            close_and_open(self.driver)
 
     def run_step(self, step_info):
         '''innermost run loop, where the step function run actually'''
@@ -65,14 +69,18 @@ class DebugRunner(BaseRunner):
                     arg = '{}={}'.format(name, self._check_value(value['value'], 'keyword')) if value['value'] else None
                     s += ', ' + arg if arg else ''
             if keyword.inner_args:
-                exec_command = 'self.r = keyword.func(self.driver, *a{})'.format(s)
+                if keyword.name == 'new_browser':
+                    self.reset_driver()
+                else:
+                    exec_command = 'self.r = keyword.func(self.driver, *a{})'.format(s)
+                    exec(exec_command)
             else:
                 exec_command = 'self.r = keyword.func(*a{})'.format(s)
+                exec(exec_command)
             if hasattr(step_info, 'description') and step_info.description:
                 logger.info('执行步骤: 类型{}, 关键字{}, 描述:{}'.format(step_info.type, keyword.name, step_info.description))
             else:
                 logger.info('执行步骤: 类型{}, 关键字{}'.format(step_info.type, keyword.name))
-            exec(exec_command)
             if step_info.type == 'keyword' and step_info.return_var:
                 self.dyn_var[step_info.return_var[0]] = self.r
                 self._input('')
