@@ -15,8 +15,8 @@ def load(path):
     with open(path, 'rb') as f:
         try:
             data = yaml.load(f, Loader=LineLoader)
-        except ParserError:
-            raise YamlParseError
+        except ParserError as e:
+            raise YamlParseError([e.context_mark, e.context, e.problem_mark, e.problem])
     return data
 
 
